{% extends 'allianceauth/base.html' %}

{% load i18n %}

{% block page_title %}{% translate "fleet" %}{% endblock %}

{% block content %}
    <br />
    <nav class="navbar navbar-default">
        <div class="container-fluid">
            <div class="navbar-header">
                <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                    <span class="sr-only">{% translate "Toggle navigation" %}</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>

                <a class="navbar-brand" href="{% url 'fleet:dashboard' %}">{% translate "Available Fleets" %}</a>
            </div>

            <ul class="nav navbar-nav">
                {% if perms.fleet.manage %}
                    <li> <a href="{% url 'fleet:create_fleet' %}">{% translate "Create Fleet" %}</a></li>
                {% endif %}
            </ul>
        </div>
    </nav>

    {% block fleet_block %}{% endblock %}
{% endblock %}
