/* bootstrap theme overrides
------------------------------------------------------------------------------------- */
@media all {
    html {
        /*font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;*/
        font-family: Roboto, "Helvetica Neue", sans-serif;
        font-size: 100%;
    }

    body {
        /*font-family: "Roboto";*/
        background: url('https://web.ccpgamescdn.com/aws/eveonline/sso/background.jpg') no-repeat center center fixed;
        background-color: rgb(39, 43, 48);
        -moz-background-size: cover;
        -o-background-size: cover;
        -webkit-background-size: cover;
        background-size: cover;
        color: rgb(200, 200, 200);
        font-family: Roboto, "Helvetica Neue", sans-serif;
        font-size: 100%;
    }

    .h1, .h2, .h3, .h4, .h5, .h6,
    h1, h2, h3, h4, h5, h6 {
        font-family: Roboto, "Helvetica Neue", sans-serif;
        font-weight: 400;
    }

    .tooltip {
        font-family: Roboto, "Helvetica Neue", sans-serif;
    }

    .popover {
        font-family: Roboto, "Helvetica Neue", sans-serif;
    }

    .page-header {
        border-bottom: none;
    }

    .nav > li > a {
        padding: 10px 10px;
    }

    .navbar {
        background-image: none;
        background-repeat: no-repeat;
        border: 1px solid rgba(0, 0, 0, 0.6);
        filter: none;
        text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    }

    .navbar-nav > li > a {
        line-height: 20px;
        padding-bottom: 10px;
        padding-top: 10px;
    }

    .navbar .navbar-nav > li > a:hover {
        background-image: none;
        background-repeat: no-repeat;
        border-left-color: transparent;
        -webkit-filter: none;
        filter: none;
    }

    .navbar-inverse .navbar-nav > li > a:hover {
        background-image: none;
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
    }

    .navbar-default {
        background-color: rgb(58, 63, 68);
        border-color: rgb(43, 46, 50);
    }

    .nav-pills > li > a {
        background-image: none;
        background-repeat: no-repeat;
        border: none;
        color: rgb(255, 255, 255);
        -webkit-filter: none;
        filter: none;
    }

    .nav-pills > li > a:hover {
        background: rgb(236, 240, 241);
        background-image: none;
        border: none;
        color: rgb(54, 54, 54);
        filter: none;
    }

    .nav-pills > li > a.active {
        background: rgb(62, 68, 76);
    }

    .nav-pills > li.active > a,
    .nav-pills > li.active > a:focus,
    .nav-pills > li.active > a:hover {
        background-color: rgb(62, 68, 76);
        background-image: none;
        background-repeat: no-repeat;
        border: none;
        -webkit-filter: none;
        filter: none;
    }

    /* in case someone puts the nav into a panel header ...
    ------------------------------------------------------- */
    .panel-heading .nav-pills > li > a:hover,
    .panel-heading .nav-pills > li.active > a,
    .panel-heading .nav-pills > li.active > a:focus,
    .panel-heading .nav-pills > li.active > a:hover {
        background-color: rgba(200, 200, 200, 0.2);
        background-image: none;
        background-repeat: no-repeat;
        border: none;
        -webkit-filter: none;
        filter: none;
    }

    .nav-pills > li.disabled > a,
    .nav-pills > li.disabled > a:hover {
        background-image: none;
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
    }

    .pagination > li > a,
    .pagination > li > span {
        background-image: linear-gradient(rgb(72, 78, 85), rgb(58, 63, 68) 60%, rgb(49, 53, 57));
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
        text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    }

    .pagination > li > a:hover,
    .pagination > li > span:hover {
        background-image: linear-gradient(rgb(2, 2, 2), rgb(16, 17, 18) 40%, rgb(20, 22, 24));
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
    }

    .pagination > li.active > a,
    .pagination > li.active > span {
        background-image: linear-gradient(rgb(2, 2, 2), rgb(16, 17, 18) 40%, rgb(20, 22, 24));
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
    }

    .pagination > li.disabled > a,
    .pagination > li.disabled > a:hover,
    .pagination > li.disabled > span,
    .pagination > li.disabled > span:hover {
        background-color: transparent;
        background-image: linear-gradient(rgb(72, 78, 85), rgb(58, 63, 68) 60%, rgb(49, 53, 57));
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
    }

    .pager > li > a {
        background-image: linear-gradient(rgb(72, 78, 85), rgb(58, 63, 68) 60%, rgb(49, 53, 57));
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
        text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    }

    .pager > li > a:hover {
        background-image: linear-gradient(rgb(2, 2, 2), rgb(16, 17, 18) 40%, rgb(20, 22, 24));
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
    }

    .pager > li.disabled > a,
    .pager > li.disabled > a:hover {
        background-color: transparent;
        background-image: linear-gradient(rgb(72, 78, 85), rgb(58, 63, 68) 60%, rgb(49, 53, 57));
        background-repeat: no-repeat;
        -webkit-filter: none;
        filter: none;
    }

    table {
        background-color: transparent;
    }

    .table > thead > tr > th,
    .table > tbody > tr > th,
    .table > tfoot > tr > th,
    .table > thead > tr > td,
    .table > tbody > tr > td,
    .table > tfoot > tr > td {
        border-top: none;
    }

    .table .table {
        background-color: rgba(39, 43, 48, 0.6);
    }

    .table-striped > tbody > tr:nth-of-type(odd) {
        background-color: rgba(53, 58, 65, 0.75);
    }

    .table-hover > tbody > tr:hover {
        background-color: rgba(73, 81, 90, 0.8);
    }

    .table > thead > tr > td.active,
    .table > tbody > tr > td.active,
    .table > tfoot > tr > td.active,
    .table > thead > tr > th.active,
    .table > tbody > tr > th.active,
    .table > tfoot > tr > th.active,
    .table > thead > tr.active > td,
    .table > tbody > tr.active > td,
    .table > tfoot > tr.active > td,
    .table > thead > tr.active > th,
    .table > tbody > tr.active > th,
    .table > tfoot > tr.active > th {
        background-color: rgba(73, 81, 90, 0.8);
    }

    .table-hover > tbody > tr > td.active:hover,
    .table-hover > tbody > tr > th.active:hover,
    .table-hover > tbody > tr.active:hover > td,
    .table-hover > tbody > tr:hover > .active,
    .table-hover > tbody > tr.active:hover > th {
        background-color: rgba(62, 68, 76, 0.8);
    }

    .table > thead > tr > td.success,
    .table > tbody > tr > td.success,
    .table > tfoot > tr > td.success,
    .table > thead > tr > th.success,
    .table > tbody > tr > th.success,
    .table > tfoot > tr > th.success,
    .table > thead > tr.success > td,
    .table > tbody > tr.success > td,
    .table > tfoot > tr.success > td,
    .table > thead > tr.success > th,
    .table > tbody > tr.success > th,
    .table > tfoot > tr.success > th {
        background-color: rgba(98, 196, 98, 0.5);
    }

    .table-hover > tbody > tr > td.success:hover,
    .table-hover > tbody > tr > th.success:hover,
    .table-hover > tbody > tr.success:hover > td,
    .table-hover > tbody > tr:hover > .success,
    .table-hover > tbody > tr.success:hover > th {
        background-color: rgba(79, 189, 79, 0.5);
    }

    .table > thead > tr > td.info,
    .table > tbody > tr > td.info,
    .table > tfoot > tr > td.info,
    .table > thead > tr > th.info,
    .table > tbody > tr > th.info,
    .table > tfoot > tr > th.info,
    .table > thead > tr.info > td,
    .table > tbody > tr.info > td,
    .table > tfoot > tr.info > td,
    .table > thead > tr.info > th,
    .table > tbody > tr.info > th,
    .table > tfoot > tr.info > th {
        background-color: rgba(91, 192, 222, 0.5);
    }

    .table-hover > tbody > tr > td.info:hover,
    .table-hover > tbody > tr > th.info:hover,
    .table-hover > tbody > tr.info:hover > td,
    .table-hover > tbody > tr:hover > .info,
    .table-hover > tbody > tr.info:hover > th {
        background-color: rgba(70, 184, 218, 0.5);
    }

    .table > thead > tr > td.warning,
    .table > tbody > tr > td.warning,
    .table > tfoot > tr > td.warning,
    .table > thead > tr > th.warning,
    .table > tbody > tr > th.warning,
    .table > tfoot > tr > th.warning,
    .table > thead > tr.warning > td,
    .table > tbody > tr.warning > td,
    .table > tfoot > tr.warning > td,
    .table > thead > tr.warning > th,
    .table > tbody > tr.warning > th,
    .table > tfoot > tr.warning > th {
        background-color: rgba(248, 148, 6, 0.5);
    }

    .table-hover > tbody > tr > td.warning:hover,
    .table-hover > tbody > tr > th.warning:hover,
    .table-hover > tbody > tr.warning:hover > td,
    .table-hover > tbody > tr:hover > .warning,
    .table-hover > tbody > tr.warning:hover > th {
        background-color: rgba(223, 133, 5, 0.5);
    }

    .table > thead > tr > td.danger,
    .table > tbody > tr > td.danger,
    .table > tfoot > tr > td.danger,
    .table > thead > tr > th.danger,
    .table > tbody > tr > th.danger,
    .table > tfoot > tr > th.danger,
    .table > thead > tr.danger > td,
    .table > tbody > tr.danger > td,
    .table > tfoot > tr.danger > td,
    .table > thead > tr.danger > th,
    .table > tbody > tr.danger > th,
    .table > tfoot > tr.danger > th {
        background-color: rgba(238, 95, 91, 0.5);
    }

    .table-hover > tbody > tr > td.danger:hover,
    .table-hover > tbody > tr > th.danger:hover,
    .table-hover > tbody > tr.danger:hover > td,
    .table-hover > tbody > tr:hover > .danger,
    .table-hover > tbody > tr.danger:hover > th {
        background-color: rgba(236, 72, 68, 0.5);
    }

    .btn-sm,
    .btn-group-sm > .btn {
        font-size: 13px;
        padding: 6px 9px;
    }

    .list-group-item {
        background-color: rgba(50, 56, 62, 0.6);
    }

    .list-group-item-success {
        background-color: rgba(98, 196, 98, 0.6);
    }

    a.list-group-item-success:hover,
    button.list-group-item-success:hover,
    a.list-group-item-success:focus,
    button.list-group-item-success:focus {
        background-color: rgba(79, 189, 79, 0.6);
    }

    .list-group-item-info {
        background-color: rgba(91, 192, 222, 0.6);
    }

    a.list-group-item-info:hover,
    button.list-group-item-info:hover,
    a.list-group-item-info:focus,
    button.list-group-item-info:focus {
        background-color: rgba(70, 184, 218, 0.6);
    }

    .list-group-item-warning {
        background-color: rgba(248, 148, 6, 0.6);
    }

    a.list-group-item-warning:hover,
    button.list-group-item-warning:hover,
    a.list-group-item-warning:focus,
    button.list-group-item-warning:focus {
        background-color: rgba(223, 133, 5, 0.6);
    }

    .list-group-item-danger {
        background-color: rgba(238, 95, 91, 0.6);
    }

    a.list-group-item-danger:hover,
    button.list-group-item-danger:hover,
    a.list-group-item-danger:focus,
    button.list-group-item-danger:focus {
        background-color: rgba(236, 72, 68, 0.6);
    }

    .valign-middle,
    .table > tbody > tr > td.valign-middle,
    .table > tbody > tr > th.valign-middle,
    .table > tfoot > tr > td.valign-middle,
    .table > tfoot > tr > th.valign-middle,
    .table > thead > tr > td.valign-middle {
        vertical-align: middle;
    }

    td p:last-child {
        margin-bottom: 0;
    }

    .text-decoration-none {
        text-decoration: none !important;
    }
}

/* eve time in navbar
------------------------------------------------------------------------------------- */
@media all {
    .nav-item-eve-time .eve-time-wrapper {
        border-left: 1px solid rgba(255, 255, 255, 0.1);
        border-right: 1px solid rgba(0, 0, 0, 0.2);
        color: rgb(200, 200, 200);
        line-height: 20px;
        padding: 10px;
        /*padding-bottom: 10px;*/
        /*padding-top: 10px;*/
    }
}

/* display
------------------------------------------------------------------------------------- */
@media all {
    .d-none {
        display: none !important;
    }

    .d-inline {
        display: inline !important;
    }

    .d-inline-block {
        display: inline-block !important;
    }

    .d-block {
        display: block !important;
    }

    .d-table {
        display: table !important;
    }

    .d-table-row {
        display: table-row !important;
    }

    .d-table-cell {
        display: table-cell !important;
    }

    .d-flex {
        display: -webkit-box !important;
        display: -ms-flexbox !important;
        display: flex !important;
    }

    .d-inline-flex {
        display: -webkit-inline-box !important;
        display: -ms-inline-flexbox !important;
        display: inline-flex !important;
    }
}

/* auth base styles
------------------------------------------------------------------------------------- */
@media all {
    #wrapper {
        background-color: rgba(48, 48, 48, 0.75);
        color: rgb(255, 2552, 255);
        padding: 0;
        width: 100%;
    }

    .alliance-auth-background {
        background-color: rgba(39, 43, 48, 0.95);
        bottom: 0;
        margin: 0;
        position: fixed;
        top: 0;
        width: 100%;
        z-index: 0;
    }

    .alliance-auth-content {
        margin-bottom: 2rem;
        position: relative;
    }

    img {
        border-radius: 6px;
        height: auto;
        max-width: 100%;
    }

    .img-circle {
        border-radius: 6px;
    }

    .img-default {
        border-radius: 0;
    }

    .gray-icon-color .fa {
        color: rgb(80, 80, 80);
    }

    .notification-bell-color {
        color: rgb(168, 143, 30);
    }

    .auth-navbar-top .navbar-brand {
        padding: 10px 15px 15px 16px;
    }

    .auth-navbar-top {
        margin-bottom: 0;
    }

    .auth-side-navbar-collapse {
        padding-left: 0;
    }

    #site-body-wrapper {
        margin-right: 0;
    }

    .breadcrumb {
        background-image: linear-gradient(rgb(72, 78, 85), rgb(58, 63, 68) 60%, rgb(49, 53, 57));
        background-repeat: no-repeat;
        border: 1px solid rgba(0, 0, 0, 0.6);
        -webkit-filter: none;
        filter: none;
        text-shadow: 1px 1px 1px rgba(0, 0, 0, 0.3);
    }

    /* Horizontal list group */
    ul.list-group.list-group-horizontal {
        display: table;
        width: 100%;
    }

    ul.list-group.list-group-horizontal > li.list-group-item {
        display: table-cell;
        max-width: 0;
    }

    .flex-center-horizontal {
        justify-content: center;
    }
}

/* navbar
------------------------------------------------------------------------------------- */
@media all {
    .navbar-nav > li.top-user-menu.with-main-character a {
        padding: 9px 15px;
    }

    .navbar-nav > li.top-user-menu.with-main-character > .dropdown-menu {
        padding-top: 0.5rem;
    }

    .auth-side-navbar {
        background-color: rgb(58, 63, 68);
    }

    .auth-side-navbar .nav-pills > li > a.active,
    .auth-side-navbar .nav-pills > li > a:hover {
        background-color: rgb(39, 43, 46);
    }

    .auth-side-navbar .nav-stacked > li + li:last-child {
        margin-bottom: 2px;
    }

    .auth-side-navbar .navbar-collapse {
        box-shadow: none;
    }

    .navbar-static-top {
        position: static;
    }
}

/* labels
------------------------------------------------------------------------------------- */
@media all {
    .label {
        padding: 0.2rem;
    }

    .label-default {
        background-color: rgba(58, 63, 68, 0.6);
    }

    .label-default[href]:hover,
    .label-default[href]:focus {
        background-color: rgba(35, 38, 40, 0.6);
    }

    .label-primary {
        background-color: rgba(122, 130, 136, 0.6);
    }

    .label-primary[href]:hover,
    .label-primary[href]:focus {
        background-color: rgba(98, 104, 109, 0.6);
    }

    .label-success {
        background-color: rgba(98, 196, 98, 0.6);
    }

    .label-success[href]:hover,
    .label-success[href]:focus {
        background-color: rgba(66, 177, 66, 0.6);
    }

    .label-info {
        background-color: rgba(91, 192, 222, 0.6);
    }

    .label-info[href]:hover,
    .label-info[href]:focus {
        background-color: rgba(49, 176, 213, 0.6);
    }

    .label-warning {
        background-color: rgba(248, 148, 6, 0.6);
    }

    .label-warning[href]:hover,
    .label-warning[href]:focus {
        background-color: rgba(198, 118, 5, 0.6);
    }

    .label-danger {
        background-color: rgba(238, 95, 91, 0.6);
    }

    .label-danger[href]:hover,
    .label-danger[href]:focus {
        background-color: rgba(233, 50, 45, 0.6);
    }

    .label-tnnt-default {
        background-color: rgb(192, 192, 192);
        border-left: 5px solid rgb(0, 0, 0);
        color: rgb(54, 54, 54);
        display: inline-block;
        font-size: 1rem;
        font-weight: normal;
        padding: 0.625rem 0.625rem 0.625rem 0.4375rem;
    }
}

/* alerts
------------------------------------------------------------------------------------- */
@media all {
    .alert-success {
        background-color: rgba(98, 196, 98, 0.5);
    }

    .alert-success hr {
        border-top-color: rgb(85, 177, 66);
    }

    .alert-success .alert-link {
        color: rgb(230, 230, 230);
    }

    .alert-info {
        background-color: rgba(91, 192, 222, 0.5);
    }

    .alert-info hr {
        border-top-color: rgb(42, 199, 210);
    }

    .alert-info .alert-link {
        color: rgb(230, 230, 230);
    }

    .alert-warning {
        background-color: rgba(248, 148, 6, 0.5);
    }

    .alert-warning hr {
        border-top-color: rgb(208, 90, 5);
    }

    .alert-warning .alert-link {
        color: rgb(230, 230, 230);
    }

    .alert-danger {
        background-color: rgba(238, 95, 91, 0.5);
    }

    .alert-danger hr {
        border-top-color: rgb(234, 54, 79);
    }

    .alert-danger .alert-link {
        color: rgb(230, 230, 230);
    }
}

/* progress bar
------------------------------------------------------------------------------------- */
@media all {
    .progress {
        background-color: rgba(28, 30, 34, 0.5);
    }

    .progress-bar-success {
        background-color: rgba(98, 196, 98, 0.5);
    }

    .progress-bar-info {
        background-color: rgba(91, 192, 222, 0.5);
    }

    .progress-bar-warning {
        background-color: rgba(248, 148, 6, 0.5);
    }

    .progress-bar-danger {
        background-color: rgba(238, 95, 91, 0.5);
    }
}

/* panels
------------------------------------------------------------------------------------- */
@media all {
    .panel {
        background-color: rgba(200, 200, 200, 0.2);
        border: none;
    }

    .panel-primary {
        border-color: rgba(200, 200, 200, 0.6);
    }

    .panel-title, .modal-title {
        color: inherit;
        display: block;
        /*font-family: Roboto, "Helvetica Neue", sans-serif;*/
        font-family: Georgia, Times, serif;
        font-size: 1rem;
        /*line-height: 1.1;*/
        font-weight: 700;
        margin-bottom: 0.25rem;
        margin-top: 0.25rem;
        text-shadow: -1px -1px 0 rgba(0, 0, 0, 0.3);
    }

    .panel-body {
        min-height: 100px;
    }

    .panel-default > .panel-heading {
        background-color: rgba(62, 68, 76, 0.6);
    }

    .panel-default > .panel-heading .badge {
        background-color: rgba(200, 200, 200, 0.75);
    }

    .panel-primary > .panel-heading {
        background-color: rgba(122, 130, 136, 0.6);
    }

    .panel-primary > .panel-heading .badge {
        background-color: rgba(255, 255, 255, 0.75);
    }

    .panel-success > .panel-heading {
        background-color: rgba(98, 196, 98, 0.6);
    }

    .panel-success > .panel-heading .badge {
        background-color: rgba(255, 255, 255, 0.75);
    }

    .panel-info {
        border-color: rgba(0, 0, 0, 0.6);
    }

    .panel-info > .panel-heading {
        background-color: rgba(91, 192, 222, 0.6);
    }

    .panel-info > .panel-heading .badge {
        background-color: rgba(255, 255, 255, 0.75);
    }

    .panel-warning > .panel-heading {
        background-color: rgba(248, 148, 6, 0.6);
    }

    .panel-warning > .panel-heading .badge {
        background-color: rgba(255, 255, 255, 0.75);
    }

    .panel-danger > .panel-heading {
        background-color: rgba(238, 95, 91, 0.6);
    }

    .panel-danger > .panel-heading .badge {
        background-color: rgba(255, 255, 255, 0.75);
    }
}

/* tables
------------------------------------------------------------------------------------- */
@media all {
    .table-striped > tbody > tr:nth-of-type(odd) {
        background-color: rgba(62, 68, 76, 0.5);
    }

    /* style group headers within a table */
    .table-striped > tbody > tr.tr-group, .tr-group {
        background-color: rgb(62, 68, 76);
        font-weight: bold;
    }

    .table-hover > tbody > tr:nth-of-type(odd):hover {
        background-color: rgba(73, 81, 90, 0.8);
    }
}

/* highlight active menu items
------------------------------------------------------------------------------------- */
@media all {
    .nav-pills > li > a.active,
    .nav-pills > li > a:hover {
        background-color: rgb(62, 68, 76);
        color: rgb(255, 255, 255);
    }
}

/* Small devices (tablets, 768px and up)
------------------------------------------------------------------------------------- */
@media (min-width: 768px) {
    /* class for vertically aligning columns in a bootstrap row */
    .row.vertical-flexbox-row2 {
        display: -webkit-box;
        display: -webkit-flex;
        display: -ms-flexbox;
        display: flex;
        flex-wrap: wrap;
    }

    .row.vertical-flexbox-row2 > [class*='col-'] {
        display: flex;
        flex-direction: column;
    }
}

/* Alliance Auth Bootstrap fixes
------------------------------------------------------------------------------------- */
@media all and (min-width: 768px) {
    .site-body-wrapper {
        margin-left: -15px;
    }
}

/* navbar
------------------------------------------------------------------------------------- */
@media all and (min-width: 768px) {
    .navbar-nav > li > a {
        padding-bottom: 15px;
        padding-top: 15px;
    }

    .auth-side-navbar {
        background-color: transparent;
    }

    .auth-side-navbar .nav-pills > li > a.active,
    .auth-side-navbar .nav-pills > li > a:hover {
        background-color: rgb(62, 68, 76);
    }

    .navbar-static-top {
        position: fixed;
        top: 0;
        width: 100%;
    }

    .site-body-wrapper {
        margin-top: 53px;
    }
}

/* eve time in navbar
------------------------------------------------------------------------------------- */
@media all and (min-width: 768px) {
    .nav-item-eve-time .eve-time-wrapper {
        padding-bottom: 15px;
        padding-top: 15px;
    }
}
