{% extends 'allianceauth/base.html' %}
{% load i18n %}

{% block page_title %}{{ app_title }}{% endblock %}

{% block content %}
    <h2 class="text-center">{{ page_title }}</h2>
    <div class="clearfix">
        {% block details %}{% endblock %}
    </div>
{% endblock %}
